@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11946 2020-02-22 13:22:03Z Trista $
+# $Id: models.py 11979 2020-03-18 04:52:03Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-02-22 22:22:03 +0900 (週六, 22 二月 2020) $
-# $Revision: 11946 $
+# $Date: 2020-03-18 13:52:03 +0900 (週三, 18 三月 2020) $
+# $Revision: 11979 $
 
 from functools import wraps
 from django import forms
@@ -21,6 +21,8 @@ from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from cms.models import CMSPlugin
+from djangocms_forms.models import FormDefinition
+from filer.fields.file import FilerFileField
 from aldryn_categories.models import Category
 from aldryn_newsblog.models import Article
 from aldryn_newsblog import models as newsblogModels
@@ -182,3 +184,32 @@ utilities.get_plugin_index_data = get_plugin_index_data
 newsblogModels.get_plugin_index_data = get_plugin_index_data
 
 
+# CMSPlugin FormDefinition
+class CallToActionModel(CMSPlugin):
+    
+    targetFile = FilerFileField(
+        verbose_name=_('Shared file'),
+        null=True,
+        blank=True,
+        on_delete=models.SET_NULL,
+    )
+    linkUrl = models.URLField(
+        verbose_name=_('External URL'),
+        blank=True,
+        max_length=2040,
+        help_text=_('The file link to an external URL.'),
+    )
+    renderTemplate = models.CharField(
+        _('Call To Action Template'), max_length=150, blank=True,
+        choices=_settings.CALL_TO_ACTION_TEMPLATES,
+        default=_settings.CALL_TO_ACTION_DEFAULT_TEMPLATE,
+    )
+
+
+class CallToActionStatistics(models.Model):
+    action = models.ForeignKey(CallToActionModel)
+    token = models.CharField(max_length=80)
+    email = models.CharField(max_length=500)
+    count = models.IntegerField(default=0)
+    url = models.CharField(max_length=500)
+
