@@ -16,10 +16,10 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='OscarOffer',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='cms_oscar_oscaroffer', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='cms_oscar_oscaroffer', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('limit', models.PositiveIntegerField(default=6)),
                 ('renderTemplate', models.CharField(default=b'cms_oscar/Latest.html', max_length=150, verbose_name=b'Latest Template', blank=True, choices=[(b'cms_oscar/Latest.html', 'Default'), (b'cms_oscar/Products.html', 'Products')])),
-                ('offer', models.ForeignKey(related_name='+', default=None, blank=True, to='offer.ConditionalOffer', null=True)),
+                ('offer', models.ForeignKey(related_name='+', default=None, blank=True, to='offer.ConditionalOffer', null=True, on_delete=models.CASCADE)),
             ],
             options={
                 'abstract': False,
