@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11641 2019-06-19 07:33:01Z Lavender $
+# $Id: models.py 11984 2020-03-19 12:21:32Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-19 16:33:01 +0900 (週三, 19 六月 2019) $
-# $Revision: 11641 $
+# $Date: 2020-03-19 21:21:32 +0900 (週四, 19 三月 2020) $
+# $Revision: 11984 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 class URL(models.Model):
-    url = models.CharField(max_length=400, editable=False, db_index=True)
+    url = models.CharField(max_length=400, editable=False, db_index=True, unique=True)
     viewCount = models.PositiveIntegerField(
         verbose_name=_("View count"), default=0)
     likeCount = models.PositiveIntegerField(
