@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11069 2018-05-21 10:18:52Z Lavender $
+# $Id: views.py 11641 2019-06-19 07:33:01Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-21 18:18:52 +0800 (週一, 21 五月 2018) $
-# $Revision: 11069 $
+# $Date: 2019-06-19 16:33:01 +0900 (週三, 19 六月 2019) $
+# $Revision: 11641 $
 
 from django.db.models.signals import post_save
 from django.dispatch import receiver
@@ -22,20 +22,6 @@ from Zephyrus.facebook.models import APIData
 from Zephyrus.statistics.models import URL
 from Zephyrus.comment.models import CommentConfig, Comment
 
-@receiver(post_save, sender=APIData)
-def updateURL(sender, instance, **kwargs):
-    obj, created = URL.objects.get_or_create(
-        url=instance.url,
-    )
-
-    # 處理 fb 的 likeCount
-    obj.likeCount = instance.likeCount
-
-    # 處理 fb 的 commentCount
-    obj.commentCount = instance.commentCount
-    
-    obj.save()
-
 @receiver(post_save, sender=Comment)
 def updateCommentCount(sender, instance, **kwargs):
     obj, created = URL.objects.get_or_create(
